@@ -17,7 +17,7 @@
 
 open Sexplib.Std
 
-exception Parse_error of string * string with sexp
+exception Parse_error of string * string [@@deriving sexp]
 
 type scope =
 | Point
@@ -27,7 +27,7 @@ type scope =
 | Site
 | Organization
 | Global
-with sexp
+[@@deriving sexp]
 
 let (~|) = Int32.of_int
 let (|~) = Int32.to_int
@@ -237,8 +237,8 @@ module V4 = struct
   let routers     = make 224   0   0   2
 
   module Prefix = struct
-    type addr = t with sexp
-    type t = addr * int with sexp
+    type addr = t [@@deriving sexp]
+    type t = addr * int [@@deriving sexp]
 
     let compare (pre,sz) (pre',sz') =
       let c = compare pre pre' in
@@ -315,6 +315,9 @@ module V4 = struct
 
     let mem ip (pre,sz) = let host = 32 - sz in (ip >|> host) = (pre >|> host)
 
+    let subset ~subnet:(pre1,sz1) ~network:(pre2,sz2) =
+      sz1 >= sz2 && mem pre1 (pre2,sz2)
+
     let of_addr ip = make 32 ip
 
     let global          = make  0 (ip   0   0 0 0)
@@ -688,8 +691,8 @@ module V6 = struct
   let site_routers      = make 0xff05 0 0 0 0 0 0 2
 
   module Prefix = struct
-    type addr = t with sexp
-    type t = addr * int with sexp
+    type addr = t [@@deriving sexp]
+    type t = addr * int [@@deriving sexp]
 
     let compare (pre,sz) (pre',sz') =
       let c = compare pre pre' in
@@ -772,6 +775,9 @@ module V6 = struct
       let m = mask sz in
       logand ip m = logand pre m
 
+    let subset ~subnet:(pre1,sz1) ~network:(pre2,sz2) =
+      sz1 >= sz2 && mem pre1 (pre2,sz2)
+
     let of_addr ip = make 128 ip
 
     let global_unicast_001  = make   3 (ip 0x2000 0 0 0 0 0 0 0)
@@ -829,8 +835,8 @@ module V6 = struct
   let is_private i = (scope i) <> Global
 end
 
-type ('v4,'v6) v4v6 = V4 of 'v4 | V6 of 'v6 with sexp
-type t = (V4.t,V6.t) v4v6 with sexp
+type ('v4,'v6) v4v6 = V4 of 'v4 | V6 of 'v6 [@@deriving sexp]
+type t = (V4.t,V6.t) v4v6 [@@deriving sexp]
 
 let compare a b = match a,b with
   | V4 a, V4 b -> V4.compare a b
@@ -909,8 +915,8 @@ module Prefix = struct
     let to_v6 = to_v6
   end
 
-  type addr = t with sexp
-  type t = (V4.Prefix.t,V6.Prefix.t) v4v6 with sexp
+  type addr = t [@@deriving sexp]
+  type t = (V4.Prefix.t,V6.Prefix.t) v4v6 [@@deriving sexp]
 
   let compare a b = match a,b with
     | V4 a , V4 b -> V4.Prefix.compare a b
@@ -953,6 +959,9 @@ module Prefix = struct
 
   let mem ip prefix = V6.Prefix.mem (Addr.to_v6 ip) (to_v6 prefix)
 
+  let subset ~subnet ~network =
+    V6.Prefix.subset ~subnet:(to_v6 subnet) ~network:(to_v6 network)
+
   let of_addr = function
     | V4 p -> V4 (V4.Prefix.of_addr p)
     | V6 p -> V6 (V6.Prefix.of_addr p)
